# Kindness

Kindness is a Python package designed to promote kindness, gratitude, and positivity. It provides simple functions to generate random acts of kindness, gratitude messages, and compliments.

## Installation

You can install the Kindness package using pip:

```
pip install kindness
```

## Usage

Here's a quick example of how to use the Kindness package:

```python

import kindness
print(kindness.random_act())
print(kindness.gratitude())
print(kindness.compliment())
```
```python
from kindness import random_act, gratitude, compliment

print(random_act())
print(gratitude())
print(compliment())

```

## Functions

- `random_act()`: Generates a random act of kindness.
- `gratitude()`: Generates a random thank you note to promote gratitude.
- `compliment()`: Generates a random compliment to encourage the habit of complimenting others.

## Contributing

Contributions are welcome! Please feel free to submit a Pull Request.

## License

This project is licensed under the MIT License. See the LICENSE file for details.

# LICENSE
MIT License

Copyright (c) [2024] [Nithesh K]

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
